@@ -64,6 +64,8 @@ use Socket;
 
 Constructor.  Called when this plugin is instantiated.
 
+This merely saves away the name of our plugin.
+
 =end doc
 
 =cut
@@ -74,6 +76,7 @@ sub new
     my $class = ref($proto) || $proto;
 
     my $self = {};
+    $self->{ 'name' } = $proto;
 
     # verbose?
     $self->{ 'verbose' } = $supplied{ 'verbose' } || 0;
@@ -83,6 +86,21 @@ sub new
 }
 
 
+=begin doc
+
+Return the name of this plugin.
+
+=end doc
+
+=cut
+
+sub name
+{
+    my ($self) = (@_);
+    return ( $self->{ 'name' } );
+}
+
+
 
 
 =begin doc
@@ -121,17 +139,6 @@ sub testComment
     $safe =~ s/[:\.]/-/g;
     if ( -e "$cdir/$safe" )
     {
-
-        #
-        #  Update the modification time so that it
-        # persists longer than the expected time since
-        # we've had a fresh hit.
-        #
-        $self->touchCache("$cdir/$safe");
-
-        #
-        #  Return the cached result
-        #
         return ("SPAM:Cached from HTTP;bl");
     }
 
@@ -189,11 +196,10 @@ sub testComment
     {
         mkpath( $cdir, { verbose => 0 } );
     }
-
-    #
-    #  Save in the cache.
-    #
-    $self->touchCache("$cdir/$safe");
+    open( FILE, ">", "$cdir/$safe" ) or
+      die "Failed to open $cdir/$safe - $!";
+    print FILE "\n";
+    close(FILE);
 
     #
     #  Return spam result
@@ -203,29 +209,6 @@ sub testComment
 
 
 
-
-=begin doc
-
-Create/Update the mtime of a file in the cache
-directory.
-
-=end doc
-
-=cut
-
-sub touchCache
-{
-    my ( $self, $file ) = (@_);
-
-    open( FILE, ">", $file ) or
-      return;
-    print FILE "\n";
-    close(FILE);
-}
-
-
-
-
 =begin doc
 
 Expire our cached entries once a week.
@@ -238,13 +221,10 @@ sub expire
 {
     my ( $self, $parent, $frequency ) = (@_);
 
-    #
-    #  Max age of files to keep.
-    #
-    my $max = $self->{ 'age' } || 7;
-
-    if ( $frequency eq "daily" )
+    if ( $frequency eq "weekly" )
     {
+        $self->{ 'verbose' } && print "Cleaning HTTP;bl Cache\n";
+
         my $state = $parent->getStateDir();
         my $cdir  = $state . "/cache/httpbl/";
 
@@ -252,21 +232,15 @@ sub expire
         {
 
             #
-            #  We're invoked once per day, but we only
-            # cleanup once a month.
+            #  We're invoked once per week, but we
+            # only want to remove files which are themselves
+            # older than a week.
             #
-            my $age = int( -M $entry );
-
-            if ( $age >= $max )
+            if ( -M $entry > 7 )
             {
                 $self->{ 'verbose' } && print "\tRemoving: $entry\n";
                 unlink($entry);
             }
-            else
-            {
-                $self->{ 'verbose' } &&
-                  print "\tLeaving $entry - $age days old <= $max\n";
-            }
         }
     }
 }
