@@ -51,6 +51,8 @@ use Time::HiRes qw(gettimeofday);
 
 Constructor.  Called when this plugin is instantiated.
 
+This merely saves away the name of our plugin.
+
 =end doc
 
 =cut
@@ -61,6 +63,7 @@ sub new
     my $class = ref($proto) || $proto;
 
     my $self = {};
+    $self->{ 'name' } = $proto;
 
     # verbose?
     $self->{ 'verbose' } = $supplied{ 'verbose' } || 0;
@@ -70,6 +73,21 @@ sub new
 }
 
 
+=begin doc
+
+Return the name of this plugin.
+
+=end doc
+
+=cut
+
+sub name
+{
+    my ($self) = (@_);
+    return ( $self->{ 'name' } );
+}
+
+
 
 
 =begin doc
@@ -84,13 +102,10 @@ sub expire
 {
     my ( $self, $parent, $frequency ) = (@_);
 
-    #
-    #  Max age of files to keep.
-    #
-    my $max = $self->{ 'age' } || 30;
-
     if ( $frequency eq "daily" )
     {
+        $self->{ 'verbose' } && print "Cleaning log Cache\n";
+
         my $state = $parent->getStateDir();
 
         foreach my $name (qw! ok spam !)
@@ -99,23 +114,15 @@ sub expire
 
             foreach my $entry ( glob( $dir . "/*" ) )
             {
-
                 #
                 #  We're invoked once per day, but we only
                 # cleanup once a month.
                 #
-                my $age = int( -M $entry );
-
-                if ( $age >= $max )
+                if ( -M $entry > 30 )
                 {
                     $self->{ 'verbose' } && print "\tRemoving: $entry\n";
                     unlink($entry);
                 }
-                else
-                {
-                    $self->{ 'verbose' } &&
-                      print "\tLeaving $entry - $age days old <= $max\n";
-                }
             }
         }
     }
@@ -150,7 +157,7 @@ sub logMessage
     #
     if ( $result =~ /^spam:/i )
     {
-        $result = "SPAM";
+        $result ="SPAM";
     }
 
     $result = lc($result);
